Summary:        Library for accessing USB devices
Name:           libusb1
Version:        1.0.27
Release:    1%{?dist}
Source0:        https://github.com/libusb/libusb/releases/download/v%{version}/libusb-%{version}.tar.bz2
License:        LGPL-2.1-or-later
URL:            http://libusb.info
BuildRequires:  systemd-devel doxygen libtool
BuildRequires:  umockdev-devel
BuildRequires:  make
BuildRequires:  gcc
BuildRequires:  patchelf
Provides:       libusbx = %{version}-%{release}

%description
This package provides a way for applications to access USB devices.

libusb is a library for USB device access from Linux, macOS,
Windows, OpenBSD/NetBSD, Haiku and Solaris userspace.

libusb is abstracted internally in such a way that it can hopefully
be ported to other operating systems.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Provides:       libusbx-devel = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package devel-doc
Summary:        Development files for %{name}
Requires:       libusb1-devel = %{version}-%{release}
Provides:       libusbx-devel-doc = %{version}-%{release}
BuildArch:      noarch

%description devel-doc
This package contains API documentation for %{name}.


%package        tests-examples
Summary:        Tests and examples for %{name}
License:        LGPLv2+ and GPLv2+
Requires:       %{name} = %{version}-%{release}
Provides:       libusbx-tests-examples = %{version}-%{release}

%description tests-examples
This package contains tests and examples for %{name}.


%prep
%autosetup -p1 -n libusb-%{version}
chmod -x examples/*.c
mkdir -p m4


%build
%configure --disable-static --enable-examples-build
%{make_build}
pushd doc
make docs
popd
pushd tests
make
popd


%install
%{make_install}
patchelf --remove-rpath tests/init_context
patchelf --remove-rpath tests/set_option
patchelf --remove-rpath tests/stress
patchelf --remove-rpath tests/stress_mt
mkdir -p %{buildroot}%{_bindir}
install -m 755 tests/init_context %{buildroot}%{_bindir}/libusb-test-init_context
install -m 755 tests/set_option %{buildroot}%{_bindir}/libusb-test-set_option
install -m 755 tests/stress %{buildroot}%{_bindir}/libusb-test-stress
install -m 755 tests/stress_mt %{buildroot}%{_bindir}/libusb-test-stress_mt
install -m 755 tests/.libs/umockdev %{buildroot}%{_bindir}/libusb-test-umockdev
install -m 755 examples/.libs/testlibusb \
    %{buildroot}%{_bindir}/libusb-test-libusb
for i in fxload listdevs xusb; do
    install -m 755 examples/.libs/$i \
        %{buildroot}%{_bindir}/libusb-example-$i
done
rm %{buildroot}%{_libdir}/*.la


%check
LD_LIBRARY_PATH=libusb/.libs ldd %{buildroot}%{_bindir}/libusb-test-stress
LD_LIBRARY_PATH=libusb/.libs %{buildroot}%{_bindir}/libusb-test-init_context
LD_LIBRARY_PATH=libusb/.libs %{buildroot}%{_bindir}/libusb-test-set_option
LD_LIBRARY_PATH=libusb/.libs %{buildroot}%{_bindir}/libusb-test-stress
LD_LIBRARY_PATH=libusb/.libs %{buildroot}%{_bindir}/libusb-test-umockdev
LD_LIBRARY_PATH=libusb/.libs %{buildroot}%{_bindir}/libusb-test-libusb
LD_LIBRARY_PATH=libusb/.libs %{buildroot}%{_bindir}/libusb-example-listdevs


%files
%license COPYING
%doc AUTHORS README ChangeLog
%{_libdir}/*.so.*

%files devel
%{_includedir}/libusb-1.0
%{_libdir}/*.so
%{_libdir}/pkgconfig/libusb-1.0.pc

%files devel-doc
%doc doc/api-1.0 examples/*.c

%files tests-examples
%{_bindir}/libusb-example-fxload
%{_bindir}/libusb-example-listdevs
%{_bindir}/libusb-example-xusb
%{_bindir}/libusb-test-init_context
%{_bindir}/libusb-test-set_option
%{_bindir}/libusb-test-stress
%{_bindir}/libusb-test-stress_mt
%{_bindir}/libusb-test-umockdev
%{_bindir}/libusb-test-libusb


%changelog
* Mon Apr 15 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.0.27-1
- initial build
